@@ -2,6 +2,8 @@
 
 #define QT_FEATURE_pipewire -1
 
+#define QT_FEATURE_pipewire_screencapture -1
+
 #define QT_FEATURE_alsa -1
 
 #define QT_FEATURE_avfoundation -1
@@ -30,10 +32,12 @@
 
 #define QT_FEATURE_linux_dmabuf 1
 
-#define QT_FEATURE_vaapi 1
+#define QT_FEATURE_vaapi -1
 
 #define QT_FEATURE_mmrenderer -1
 
+#define QT_FEATURE_native_android_backend -1
+
 #define QT_FEATURE_pulseaudio 1
 
 #define QT_FEATURE_wmsdk -1
